##  Applicable Use Cases
  * [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases."): This is the initial SAP LeanIX use case, and it requires to have at least business capabilities modeled, along with applications, user groups, and ideally, IT components. To achieve quick wins, you don’t need a complete and detailed capability map but focus on the most critical business capabilities down to level 2.
  * [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach."): In this use case, it is about achieving cost savings and freeing up the budget by rationalizing, e.g., end-of-life or redundant applications. It makes sense to review, enrich, and update your BC map when you move on with that use case on your EA journey.
  * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs."): The same applies to application rationalization: Before starting your modernization initiative (e.g., cloud migration or ERP transformation), you must ensure that you have a robust BC map in place.
